Demo page

### Carousel in a list

### Carousel as divs

## Non-image content

A slide can contain other things than images. For example just a bunch of HTML.

Nulla facilisi. Ut mollis lectus ac nisl tincidunt quis varius arcu mattis. Etiam augue erat, suscipit eget rhoncus vitae, semper at massa. Etiam elementum, metus euismod tempus ultrices, magna mauris bibendum augue, in vestibulum enim sem lobortis magna. Pellentesque auctor, erat ut tempus vestibulum, velit nisi ultrices purus, ac sodales ipsum sapien sed ligula.